@@ -1,9 +1,8 @@
 /*
  * -*- coding: utf-8; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:filetype=c:et:sw=4:ts=4:sts=4:tw=100
  * libmachista.c
- * $Id: libmachista.c 120072 2014-05-14 22:29:40Z cal@macports.org $
  *
- * Copyright (c) 2011 The MacPorts Project
+ * Copyright (c) 2011-2012, 2014, 2016-2018 The MacPorts Project
  * Copyright (c) 2011 Landon Fuller <landonf@macports.org>
  * Copyright (c) 2011 Clemens Lang <cal@macports.org>
  * All rights reserved.
@@ -34,7 +33,7 @@
 #include <config.h>
 #endif
 
-/* required for asprintf(3) on OS X */
+/* required for asprintf(3) on macOS */
 #define _DARWIN_C_SOURCE
 /* required for asprintf(3) on Linux */
 #define _GNU_SOURCE
@@ -53,10 +52,11 @@
 #include <strings.h>
 
 #ifdef __MACH__
+#include <mach-o/dyld.h>
 #include <mach-o/fat.h>
 #include <mach-o/loader.h>
 
-#include <libkern/OSAtomic.h>
+#include <libkern/OSByteOrder.h>
 #endif
 
 #include "libmachista.h"
@@ -466,6 +466,11 @@ int macho_parse_file(macho_handle_t *handle, const char *filepath, const macho_t
     
     /* Open input file */
     if ((fd = open(filepath, O_RDONLY)) < 0) {
+#ifdef HAVE__DYLD_SHARED_CACHE_CONTAINS_PATH
+        if (_dyld_shared_cache_contains_path(filepath)) {
+            return MACHO_ECACHE;
+        }
+#endif /* HAVE__DYLD_SHARED_CACHE_CONTAINS_PATH */
         return MACHO_EFILE;
     }
 
@@ -560,6 +565,7 @@ const char *macho_strerror(int err) {
         /* 0x04 */ "Error allocating memory",
         /* 0x08 */ "Premature end of data, possibly corrupt file",
         /* 0x10 */ "Not a Mach-O file",
+        /* 0x20 */ "Shared cache only",
     };
     return errors[num];
 }
